# 🔮 Blue Fusion

🔮 `@fusion` is a submission to the 2025 IEEE GRSS Data Fusion Contest: [All-Weather Land Cover and Building Damage Mapping](https://www.grss-ieee.org/technical-committees/image-analysis-and-data-fusion/?tab=data-fusion-contest). 

```bash
pip install blue-fusion
```


---


[![pylint](https://github.com/kamangir/blue-fusion/actions/workflows/pylint.yml/badge.svg)](https://github.com/kamangir/blue-fusion/actions/workflows/pylint.yml) [![pytest](https://github.com/kamangir/blue-fusion/actions/workflows/pytest.yml/badge.svg)](https://github.com/kamangir/blue-fusion/actions/workflows/pytest.yml) [![bashtest](https://github.com/kamangir/blue-fusion/actions/workflows/bashtest.yml/badge.svg)](https://github.com/kamangir/blue-fusion/actions/workflows/bashtest.yml) [![PyPI version](https://img.shields.io/pypi/v/blue-fusion.svg)](https://pypi.org/project/blue-fusion/) [![PyPI - Downloads](https://img.shields.io/pypi/dd/blue-fusion)](https://pypistats.org/packages/blue-fusion)

built by 🌀 [`blue_options-4.200.1`](https://github.com/kamangir/awesome-bash-cli), based on 🔮 [`blue_fusion-4.12.1`](https://github.com/kamangir/blue-fusion).
